from concourse.lib.constants import REGISTRY_IMAGE
from concourse.lib.models.pipeline import Identifier, RegistryImage, ResourceType


def rclone() -> ResourceType:
    return ResourceType(
        name=Identifier("rclone"),
        type=REGISTRY_IMAGE,
        source=RegistryImage(repository="mitodl/concourse-rclone-resource"),
    )


def packer_validate() -> ResourceType:
    return ResourceType(
        name=Identifier("packer-validator"),
        type=REGISTRY_IMAGE,
        source=RegistryImage(repository="mitodl/concourse-packer-resource"),
    )


def packer_build() -> ResourceType:
    return ResourceType(
        name=Identifier("packer-builder"),
        type=REGISTRY_IMAGE,
        source=RegistryImage(repository="mitodl/concourse-packer-resource-builder"),
    )


def ami_resource() -> ResourceType:
    return ResourceType(
        name=Identifier("amazon-ami"),
        type=REGISTRY_IMAGE,
        source=RegistryImage(repository="jdub/ami-resource"),
    )


def s3_sync() -> ResourceType:
    return ResourceType(
        name=Identifier("s3-sync"),
        type=REGISTRY_IMAGE,
        source=RegistryImage(repository="mitodl/concourse-s3-sync-resource"),
    )


def pulumi_provisioner_resource() -> ResourceType:
    return ResourceType(
        name=Identifier("pulumi-provisioner"),
        type=REGISTRY_IMAGE,
        source=RegistryImage(repository="mitodl/concourse-pulumi-resource-provisioner"),
    )



from pathlib import Path
from typing import Optional

from pydantic import BaseModel, Extra


class Git(BaseModel):
    uri: str
    branch: str = "main"
    paths: Optional[list[Path]]
    ignore_paths: Optional[list[Path]]

    class Config:
        extra = Extra.allow




# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/concourse:ol-concourse

from setuptools import setup

setup(**{
    'install_requires': (
        'pydantic<2.0.0,>=1',
    ),
    'name': 'ol-concourse',
    'namespace_packages': (
    ),
    'package_data': {
    },
    'packages': (
        'concourse',
        'concourse.lib',
        'concourse.lib.models',
    ),
    'python_requires': '>=3.9',
    'version': '0.1.0',
})



from typing import Union

from concourse.lib.models.pipeline import Identifier, Resource
from concourse.lib.models.resource import Git


def git_repo(
    name: Identifier, uri: str, branch: str = "main", paths: list[str] = None
) -> Resource:
    return Resource(
        name=name,
        type="git",
        icon="git",
        source=Git(uri=uri, branch=branch, paths=paths),
    )


def github_release(name: Identifier, owner: str, repository: str) -> Resource:
    """Generate a github-release resource for the given owner/repository.

    :param name: The name of the resource. This will get used across subsequent pipeline steps that reference this resource.
    :type name: Identifier
    :param owner: The owner of the repository (e.g. the GitHub user or organization)
    :type owner: str
    :param repository: The name of the repository as it appears in GitHub
    :type repository: str
    :returns: A configured Concourse resource object that can be used in a pipeline.
    :rtype: Resource
    """
    return Resource(
        name=name,
        type="github-release",
        icon="github",
        check_every="24h",
        source={"repository": repository, "owner": owner, "release": True},
    )


def amazon_ami(
    name: Identifier, filters: dict[str, Union[str, bool]], region: str = "us-east-1"
) -> Resource:
    return Resource(
        name=name,
        type="amazon-ami",
        icon="server",
        check_every="30m",
        source={
            "region": region,
            "filters": filters,
        },
    )


def pulumi_provisioner(
    name: Identifier, project_name: str, project_path: str
) -> Resource:
    return Resource(
        name=name,
        type="pulumi-provisioner",
        icon="cloud-braces",
        source={
            "env_pulumi": {"AWS_SHARED_CREDENTIALS_FILE": "aws_creds/credentials"},
            "action": "update",
            "project_name": project_name,
            "source_dir": project_path,
        },
    )
